@@ -18,10 +18,10 @@
 #include <gtest/gtest.h>
 #include <fstream>
 #include <string>
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Util.hh>
-#include "ignition/fuel_tools/ClientConfig.hh"
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Util.hh>
+#include "gz/fuel_tools/ClientConfig.hh"
 #include "test/test_config.h"
 
 using namespace ignition;
@@ -30,7 +30,7 @@ using namespace fuel_tools;
 /////////////////////////////////////////////////
 /// \brief Helper to remove file according to OS, while Windows
 /// has this issue:
-/// https://github.com/ignitionrobotics/ign-common/issues/51
+/// https://github.com/gazebosim/gz-common/issues/51
 /// \todo(anyone) Remove this once Windows issue is solved.
 /// \param[in] _path Path to file to be removed.
 void removeFileTemp(const std::string &_path)
@@ -98,9 +98,9 @@ TEST(ClientConfig, CustomDefaultConfiguration)
 {
   ClientConfig config;
   ASSERT_EQ(2u, config.Servers().size());
-  EXPECT_EQ("https://fuel.ignitionrobotics.org",
-    config.Servers().front().Url().Str());
   EXPECT_EQ("https://fuel.gazebosim.org",
+    config.Servers().front().Url().Str());
+  EXPECT_EQ("https://fuel.ignitionrobotics.org",
     config.Servers()[1].Url().Str());
 
   std::string defaultCacheLocation = common::joinPaths(
@@ -137,9 +137,9 @@ TEST(ClientConfig, CustomConfiguration)
   EXPECT_TRUE(config.LoadConfig(testPath));
 
   ASSERT_EQ(4u, config.Servers().size());
-  EXPECT_EQ("https://fuel.ignitionrobotics.org",
-    config.Servers().front().Url().Str());
   EXPECT_EQ("https://fuel.gazebosim.org",
+    config.Servers().front().Url().Str());
+  EXPECT_EQ("https://fuel.ignitionrobotics.org",
     config.Servers()[1].Url().Str());
   EXPECT_EQ("https://api.ignitionfuel.org",
     config.Servers()[2].Url().Str());
@@ -166,10 +166,10 @@ TEST(ClientConfig, RepeatedServerConfiguration)
       << "# The list of servers."                 << std::endl
       << "servers:"                               << std::endl
       << "  -"                                    << std::endl
-      << "    url: https://fuel.ignitionrobotics.org"  << std::endl
+      << "    url: https://fuel.gazebosim.org"  << std::endl
       << ""                                       << std::endl
       << "  -"                                    << std::endl
-      << "    url: https://fuel.ignitionrobotics.org"  << std::endl
+      << "    url: https://fuel.gazebosim.org"  << std::endl
       << ""                                       << std::endl
       << "# Where are the assets stored in disk." << std::endl
       << "cache:"                                 << std::endl
@@ -317,7 +317,7 @@ TEST(ClientConfig, AsString)
 #else
     EXPECT_NE(str.find(".ignition\\fuel"), std::string::npos);
 #endif
-    EXPECT_NE(str.find("https://fuel.ignitionrobotics.org"), std::string::npos);
+    EXPECT_NE(str.find("https://fuel.gazebosim.org"), std::string::npos);
   }
 
   {
