@@ -17,10 +17,10 @@
 
 #include <gtest/gtest.h>
 #include <string>
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 
-#include "ignition/fuel_tools/ClientConfig.hh"
-#include "ignition/fuel_tools/CollectionIdentifier.hh"
+#include "gz/fuel_tools/ClientConfig.hh"
+#include "gz/fuel_tools/CollectionIdentifier.hh"
 
 using namespace ignition;
 using namespace fuel_tools;
@@ -123,18 +123,18 @@ TEST(CollectionIdentifier, AsString)
     std::string str =
         "Name: \n"\
         "Owner: \n"\
-        "Unique name: https://fuel.ignitionrobotics.org/collections/\n"
+        "Unique name: https://fuel.gazebosim.org/collections/\n"
         "Server:\n"
-        "  URL: https://fuel.ignitionrobotics.org\n"
+        "  URL: https://fuel.gazebosim.org\n"
         "  Version: 1.0\n"
         "  API key: \n";
 #else
     std::string str =
         "Name: \n"\
         "Owner: \n"\
-        "Unique name: https://fuel.ignitionrobotics.org/collections\n"
+        "Unique name: https://fuel.gazebosim.org/collections\n"
         "Server:\n"
-        "  URL: https://fuel.ignitionrobotics.org\n"
+        "  URL: https://fuel.gazebosim.org\n"
         "  Version: 1.0\n"
         "  API key: \n";
 #endif
@@ -161,7 +161,7 @@ TEST(CollectionIdentifier, AsPrettyString)
     CollectionIdentifier id;
     std::string str =
       "\x1B[96m\x1B[1mServer:\x1B[0m\n  "
-      "\x1B[96m\x1B[1mURL: \x1B[0m\x1B[37mhttps://fuel.ignitionrobotics.org"
+      "\x1B[96m\x1B[1mURL: \x1B[0m\x1B[37mhttps://fuel.gazebosim.org"
       "\x1B[0m\n  \x1B[96m\x1B[1mVersion: \x1B[0m\x1B[37m1.0\x1B[0m\n";
     EXPECT_EQ(str, id.AsPrettyString());
   }
