@@ -17,14 +17,14 @@
 
 #include <gtest/gtest.h>
 #include <fstream>
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/fuel_tools/FuelClient.hh"
-#include "ignition/fuel_tools/ClientConfig.hh"
-#include "ignition/fuel_tools/Result.hh"
-#include "ignition/fuel_tools/WorldIdentifier.hh"
+#include "gz/fuel_tools/FuelClient.hh"
+#include "gz/fuel_tools/ClientConfig.hh"
+#include "gz/fuel_tools/Result.hh"
+#include "gz/fuel_tools/WorldIdentifier.hh"
 
 #include "test/test_config.h"
 
@@ -145,12 +145,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://some.example.org/1.0/german/models/Cardboard Box"};
+      "https://some.example.org/1.0/openroboticstest/models/Cardboard Box"};
     EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
     EXPECT_EQ(id.Server().Url().Str(), "https://some.example.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -164,12 +164,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/1.0/german/models/Cardboard Box/4"};
+      "https://fuel.gazebosim.org/1.0/openroboticstest/models/Cardboard Box/4"};
     EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 4u);
   }
@@ -183,12 +183,13 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/5.0/german/models/Cardboard Box/6"};
+      "https://fuel.gazebosim.org/5.0/openroboticstest/models/Cardboard Box/6/"
+    };
     EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 6u);
   }
@@ -200,12 +201,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box"};
+      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box"};
     EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_FALSE(id.Server().Version().empty());
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -219,12 +220,12 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client(config);
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/tip"};
+      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box/tip"};
     EXPECT_TRUE(client.ParseModelUrl(common::URI(url), id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -254,28 +255,30 @@ TEST_F(FuelClientTest, ParseModelURL)
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/german/models/Cardboard Box/banana"};
+      "https://fuel.gazebosim.org/openroboticstest/models/Cardboard Box/banana"
+    };
     EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/banana/german/models/Cardboard Box"};
+      "https://fuel.gazebosim.org/banana/openroboticstest/models/Cardboard Box"
+    };
     EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/99/german/models/Cardboard Box"};
+      "https://fuel.gazebosim.org/99/openroboticstest/models/Cardboard Box"};
     EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
   {
     FuelClient client;
     ModelIdentifier id;
     const std::string url{
-      "https://fuel.ignitionrobotics.org/2/2/german/models"
+      "https://fuel.gazebosim.org/2/2/openroboticstest/models"
         "/Cardboard Box/banana"};
     EXPECT_FALSE(client.ParseModelUrl(common::URI(url), id));
   }
@@ -290,15 +293,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/"
-        "Cordless Drill/tip/files/meshes/cordless_drill.dae"};
+      "https://fuel.gazebosim.org/1.0/openroboticstest/models/"
+        "backpack/tip/files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openrobotics");
-    EXPECT_EQ(id.Name(), "cordless drill");
-    EXPECT_EQ(filePath, "meshes/cordless_drill.dae");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Name(), "backpack");
+    EXPECT_EQ(filePath, "model.sdf");
   }
 
   // URL - with client config
@@ -309,15 +312,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.ignitionrobotics.org/1.0/openrobotics/models/Pine Tree/tip/"
-      "files/materials/scripts/pine_tree.material"};
+      "https://fuel.gazebosim.org/1.0/openroboticstest/models/backpack/"
+        "tip/files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openrobotics");
-    EXPECT_EQ(id.Name(), "pine tree");
-    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Name(), "backpack");
+    EXPECT_EQ(filePath, "model.sdf");
   }
 
   // URL - version different from config
@@ -328,14 +331,14 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.ignitionrobotics.org/5.0/OpenRobotics/models/Pine Tree/tip/"
-      "files/model.sdf"};
+      "https://fuel.gazebosim.org/5.0/openroboticstest/models/backpack/"
+        "tip/files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openrobotics");
-    EXPECT_EQ(id.Name(), "pine tree");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Name(), "backpack");
     EXPECT_EQ(filePath, "model.sdf");
   }
 
@@ -345,16 +348,16 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.ignitionrobotics.org/OpenRobotics/models/pine tree/tip/"
-      "files/materials/scripts/pine_tree.material"};
+      "https://fuel.gazebosim.org/openroboticstest/models/backpack/tip/"
+      "files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
-    EXPECT_EQ(id.Owner(), "openrobotics");
-    EXPECT_EQ(id.Name(), "pine tree");
-    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Name(), "backpack");
+    EXPECT_EQ(filePath, "model.sdf");
   }
 
   // Unique name - with client config
@@ -365,15 +368,15 @@ TEST_F(FuelClientTest, ParseModelFileURL)
     ModelIdentifier id;
     std::string filePath;
     const common::URI modelUrl{
-      "https://fuel.ignitionrobotics.org/openrobotics/models/Pine Tree/tip/"
-      "files/materials/scripts/pine_tree.material"};
+      "https://fuel.gazebosim.org/openroboticstest/models/backpack/tip/"
+      "files/model.sdf"};
     EXPECT_TRUE(client.ParseModelFileUrl(modelUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "openrobotics");
-    EXPECT_EQ(id.Name(), "pine tree");
-    EXPECT_EQ(filePath, "materials/scripts/pine_tree.material");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
+    EXPECT_EQ(id.Name(), "backpack");
+    EXPECT_EQ(filePath, "model.sdf");
   }
 
   // Bad URL
@@ -395,10 +398,20 @@ TEST_F(FuelClientTest, ParseModelFileURL)
   }
 }
 
+class FuelClientDownloadTest
+    : public FuelClientTest,
+      public ::testing::WithParamInterface<const char *>
+{};
+
+INSTANTIATE_TEST_CASE_P(
+    FuelClientTest, FuelClientDownloadTest,
+    ::testing::Values("fuel.gazebosim.org",
+                      "fuel.ignitionrobotics.org"), );  // NOLINT
+
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
-TEST_F(FuelClientTest, DownloadModel)
+// https://github.com/gazebosim/gz-fuel-tools/issues/105
+TEST_P(FuelClientDownloadTest, DownloadModel)
 {
   // Configure to use binary path as cache
   ASSERT_EQ(0, ChangeDirectory(PROJECT_BINARY_PATH));
@@ -411,11 +424,12 @@ TEST_F(FuelClientTest, DownloadModel)
   FuelClient client(config);
   EXPECT_EQ(config.CacheLocation(), client.Config().CacheLocation());
 
+  std::string fuelServerHost = GetParam();
   // Download model from URL
   {
     // Unversioned URL should get the latest available version
     common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/chapulina/models/Test box"};
+      "https://" + fuelServerHost + "/1.0/openroboticstest/models/test box"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -431,12 +445,12 @@ TEST_F(FuelClientTest, DownloadModel)
 
     // Check it was downloaded to `2`
     auto modelPath = common::joinPaths(common::cwd(), "test_cache",
-        "fuel.ignitionrobotics.org", "chapulina", "models", "test box");
+        fuelServerHost, "openroboticstest", "models", "test box");
 
-    EXPECT_EQ(path, common::joinPaths(modelPath, "2"));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2")));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2", "model.sdf")));
-    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2",
+    EXPECT_EQ(path, common::joinPaths(modelPath, "1"));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1")));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1", "model.sdf")));
+    EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "1",
         "model.config")));
 
     // Check it wasn't downloaded to model root directory
@@ -446,14 +460,14 @@ TEST_F(FuelClientTest, DownloadModel)
     Result res3 = client.CachedModel(url, cachedPath);
     EXPECT_TRUE(res3);
     EXPECT_EQ(ResultType::FETCH_ALREADY_EXISTS, res3.Type());
-    EXPECT_EQ(common::joinPaths(modelPath, "2"), cachedPath);
+    EXPECT_EQ(common::joinPaths(modelPath, "1"), cachedPath);
   }
 
   // Download model with pbr paths from URL and check that paths are fixed
   {
     // Unversioned URL should get the latest available version
-    common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/iche033/models/Rescue Randy"};
+    common::URI url{"https://" + fuelServerHost +
+                    "/1.0/openroboticstest/models/Rescue Randy"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -469,7 +483,7 @@ TEST_F(FuelClientTest, DownloadModel)
 
     // Check it was downloaded to `2`
     auto modelPath = common::joinPaths(common::cwd(), "test_cache",
-        "fuel.ignitionrobotics.org", "iche033", "models", "rescue randy");
+        fuelServerHost, "openroboticstest", "models", "rescue randy");
 
     EXPECT_EQ(path, common::joinPaths(modelPath, "2"));
     EXPECT_TRUE(common::exists(common::joinPaths(modelPath, "2")));
@@ -505,10 +519,13 @@ TEST_F(FuelClientTest, DownloadModel)
 
   // Download model with a dependency specified within its `metadata.pbtxt`
   {
-    common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_1"};
+    common::URI url{"https://" + fuelServerHost +
+                    "/1.0/openroboticstest/models/hatchback_red_1"};
+
+    // The dependency will use the fuel.gazebosim.org URI regardless of what
+    // fuelServerHost is because it's set in the hatchback_red_1 model
     common::URI depUrl{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_1"};
+        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_1"};
 
     // Check it is not cached
     std::string cachedPath;
@@ -542,8 +559,10 @@ TEST_F(FuelClientTest, DownloadModel)
   // The dependency points to fuel.gazebosim.org.
   {
     common::URI url{
-      "https://fuel.ignitionrobotics.org/1.0/openrobotics/models/hatchback red"
+      "https://" + fuelServerHost + "/1.0/openrobotics/models/hatchback red"
     };
+    // The dependency will use the fuel.gazebosim.org URI regardless of what
+    // fuelServerHost is because it's set in the "hatchback red" model
     common::URI depUrl{
       "https://fuel.gazebosim.org/1.0/openrobotics/models/hatchback"};
 
@@ -578,7 +597,7 @@ TEST_F(FuelClientTest, DownloadModel)
   // Try using nonexistent URL
   {
     std::string url{
-        "https://fuel.ignitionrobotics.org/1.0/chapulina/models/"
+        "https://" + fuelServerHost + "/1.0/openroboticstest/models/"
           "Inexistent model"};
     std::string path;
     Result result = client.DownloadModel(common::URI(url), path);
@@ -598,7 +617,7 @@ TEST_F(FuelClientTest, DownloadModel)
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
+// https://github.com/gazebosim/gz-fuel-tools/issues/106
 TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
 {
   // Configure to use binary path as cache
@@ -615,9 +634,10 @@ TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
   // Download model with a dependency specified within its `metadata.pbtxt`
   {
     common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_red_1"};
+        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_red_1"
+    };
     common::URI depUrl{
-        "https://fuel.ignitionrobotics.org/1.0/JShep1/models/hatchback_1"};
+        "https://fuel.gazebosim.org/1.0/openroboticstest/models/hatchback_1"};
 
     ModelIdentifier id;
     ModelIdentifier depId;
@@ -672,7 +692,7 @@ TEST_F(FuelClientTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(ModelDependencies))
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
+// https://github.com/gazebosim/gz-fuel-tools/issues/106
 TEST_F(FuelClientTest, CachedModel)
 {
   // Configure to use binary path as cache and populate it
@@ -812,12 +832,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/1.0/german/worlds/Cardboard Box"};
+      "https://fuel.gazebosim.org/1.0/openroboticstest/worlds/Cardboard Box"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -831,12 +851,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/1.0/german/worlds/Cardboard Box/4"};
+      "https://fuel.gazebosim.org/1.0/openroboticstest/worlds/Cardboard Box/4"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 4u);
   }
@@ -850,12 +870,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/5.0/german/worlds/Cardboard Box/6"};
+      "https://fuel.gazebosim.org/5.0/openroboticstest/worlds/Cardboard Box/6"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 6u);
   }
@@ -867,13 +887,13 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box"};
+      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -888,12 +908,12 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client(config);
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box/tip/"};
+      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box/tip/"};
     EXPECT_TRUE(client.ParseWorldUrl(url, id));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
-    EXPECT_EQ(id.Owner(), "german");
+    EXPECT_EQ(id.Owner(), "openroboticstest");
     EXPECT_EQ(id.Name(), "cardboard box");
     EXPECT_EQ(id.Version(), 0u);
   }
@@ -920,28 +940,29 @@ TEST_F(FuelClientTest, ParseWorldUrl)
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/german/worlds/Cardboard Box/banana"};
+      "https://fuel.gazebosim.org/openroboticstest/worlds/Cardboard Box/here"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/banana/german/worlds/Cardboard Box"};
+      "https://fuel.gazebosim.org/banana/openroboticstest/worlds/Cardboard Box"
+    };
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/99/german/worlds/Cardboard Box"};
+      "https://fuel.gazebosim.org/99/openroboticstest/worlds/Cardboard Box"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
   {
     FuelClient client;
     WorldIdentifier id;
     const common::URI url{
-      "https://fuel.ignitionrobotics.org/2/2/german/worlds/Cardboard Box"
+      "https://fuel.gazebosim.org/2/2/openroboticstest/worlds/Cardboard Box"
         "/banana"};
     EXPECT_FALSE(client.ParseWorldUrl(url, id));
   }
@@ -956,11 +977,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -975,11 +996,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty sky/tip/"
+      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty sky/tip/"
       "files/empty_sky.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty sky");
@@ -994,11 +1015,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.ignitionrobotics.org/5.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.gazebosim.org/5.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -1011,11 +1032,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.ignitionrobotics.org/OpenRobotics/worlds/Empty sky/tip/"
+      "https://fuel.gazebosim.org/OpenRobotics/worlds/Empty sky/tip/"
       "files/empty_sky.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_FALSE(id.Server().Version().empty());
     EXPECT_EQ("1.0", id.Server().Version());
     EXPECT_EQ(id.Owner(), "openrobotics");
@@ -1031,11 +1052,11 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
     WorldIdentifier id;
     std::string filePath;
     const common::URI worldUrl{
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Empty/tip/"
+      "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Empty/tip/"
       "files/test.world"};
     EXPECT_TRUE(client.ParseWorldFileUrl(worldUrl, id, filePath));
 
-    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.ignitionrobotics.org");
+    EXPECT_EQ(id.Server().Url().Str(), "https://fuel.gazebosim.org");
     EXPECT_EQ(id.Server().Version(), "1.0");
     EXPECT_EQ(id.Owner(), "openrobotics");
     EXPECT_EQ(id.Name(), "empty");
@@ -1063,7 +1084,7 @@ TEST_F(FuelClientTest, ParseWorldFileUrl)
 
 //////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
+// https://github.com/gazebosim/gz-fuel-tools/issues/105
 TEST_F(FuelClientTest, DownloadWorld)
 {
   // Configure to use binary path as cache
@@ -1073,7 +1094,7 @@ TEST_F(FuelClientTest, DownloadWorld)
 
   ServerConfig server;
   server.SetUrl(common::URI(
-        "https://fuel.ignitionrobotics.org"));
+        "https://fuel.gazebosim.org"));
 
   ClientConfig config;
   config.AddServer(server);
@@ -1086,7 +1107,7 @@ TEST_F(FuelClientTest, DownloadWorld)
   // Download world from URL
   {
     // Unversioned URL should get the latest available version
-    common::URI url{"https://fuel.ignitionrobotics.org/1.0/OpenRobotics/"
+    common::URI url{"https://fuel.gazebosim.org/1.0/OpenRobotics/"
                     "worlds/Test world"};
 
     // Check it is not cached
@@ -1103,7 +1124,7 @@ TEST_F(FuelClientTest, DownloadWorld)
 
     // Check it was downloaded to `1`
     auto worldPath = common::joinPaths(common::cwd(), "test_cache",
-        "fuel.ignitionrobotics.org", "openrobotics", "worlds", "test world");
+        "fuel.gazebosim.org", "openrobotics", "worlds", "test world");
 
     EXPECT_EQ(path, common::joinPaths(worldPath, "2"));
     EXPECT_TRUE(common::exists(common::joinPaths(worldPath, "2")));
@@ -1122,7 +1143,7 @@ TEST_F(FuelClientTest, DownloadWorld)
   // Try using nonexistent URL
   {
     common::URI url{
-        "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/worlds/Bad world"};
+        "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Bad world"};
     std::string path;
     auto result = client.DownloadWorld(url, path);
     EXPECT_FALSE(result);
@@ -1141,7 +1162,7 @@ TEST_F(FuelClientTest, DownloadWorld)
 
 /////////////////////////////////////////////////
 // Windows doesn't support colons in filenames
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/106
+// https://github.com/gazebosim/gz-fuel-tools/issues/106
 TEST_F(FuelClientTest, CachedWorld)
 {
   // Configure to use binary path as cache and populate it
@@ -1331,7 +1352,7 @@ TEST_F(FuelClientTest, WorldDetails)
 
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
+// https://github.com/gazebosim/gz-fuel-tools/issues/105
 TEST_F(FuelClientTest, Models)
 {
   ClientConfig config;
@@ -1351,7 +1372,7 @@ TEST_F(FuelClientTest, Models)
   }
 
   {
-    // Uses fuel.ignitionrobotics.org by default
+    // Uses fuel.gazebosim.org by default
     ModelIter iter = client.Models(serverConfig);
     EXPECT_TRUE(iter);
   }
@@ -1363,9 +1384,55 @@ TEST_F(FuelClientTest, Models)
   }
 }
 
+//////////////////////////////////////////////////
+TEST_F(FuelClientTest, ModelsCheckCached)
+{
+  ClientConfig config;
+  std::string cacheDir = common::joinPaths(PROJECT_BINARY_PATH, "test_cache");
+  common::removeAll(cacheDir );
+  ASSERT_TRUE(common::createDirectories(cacheDir));
+  config.SetCacheLocation(cacheDir);
+  FuelClient client(config);
+  ServerConfig serverConfig;
+  ModelIdentifier modelId;
+  modelId.SetOwner("openroboticstest");
+  std::vector<Model> modelInfos;
+  {
+    for (ModelIter iter = client.Models(modelId, true); iter; ++iter)
+    {
+      modelInfos.push_back(*iter);
+    }
+  }
+  ASSERT_FALSE(modelInfos.empty());
+  // Download one of the models to test the behavior of Models() with
+  // different values for _checkCache
+  EXPECT_TRUE(client.DownloadModel(modelInfos.front().Identification()));
+  {
+    std::size_t counter = 0;
+    for (ModelIter iter = client.Models(modelId, true); iter; ++iter, ++counter)
+    {
+    }
+    std::cout << "counter: " << counter << std::endl;
+    // Expect only one result with checkCache=true because we've downloaded only
+    // one model
+    EXPECT_EQ(counter, 1u);
+    EXPECT_GT(modelInfos.size(), counter);
+  }
+
+  {
+    std::size_t counter = 0;
+    for (ModelIter iter = client.Models(modelId, false); iter;
+         ++iter, ++counter)
+    {
+    }
+    std::cout << "counter: " << counter << std::endl;
+    EXPECT_EQ(counter, modelInfos.size());
+  }
+}
+
 /////////////////////////////////////////////////
 // Protocol "https" not supported or disabled in libcurl for Windows
-// https://github.com/ignitionrobotics/ign-fuel-tools/issues/105
+// https://github.com/gazebosim/gz-fuel-tools/issues/105
 TEST_F(FuelClientTest, Worlds)
 {
   ClientConfig config;
@@ -1385,7 +1452,7 @@ TEST_F(FuelClientTest, Worlds)
   }
 
   {
-    // Uses fuel.ignitionrobotics.org by default
+    // Uses fuel.gazebosim.org by default
     WorldIter iter = client.Worlds(serverConfig);
     EXPECT_TRUE(iter);
   }
